==> cdm-core-2.0.6-sources.jar: online/sanen/cdm/QueryPKDevice.java <==
package online.sanen.cdm;

import online.sanen.cdm.api.QueryPK;
import online.sanen.cdm.api.basic.QueryType;
import online.sanen.cdm.api.basic.ResultType;
import online.sanen.cdm.api.basic.Structure;
import online.sanen.cdm.api.component.Manager;
import online.sanen.cdm.api.component.Pipeline;
import online.sanen.cdm.api.component.PipelineDivice;
import online.sanen.cdm.api.factory.PipelineFactory;
import online.sanen.cdm.factory.HandelFactory;

/**
 * @author online.sanen Date: 2017/11/23 Time： 9:39
 */
public class QueryPKDevice<T> implements QueryPK<T> {
	Structure structure;

	public QueryPKDevice(Manager manager, Class<T> entryCls, Object primarykey) {
		structure = new Structure(manager);
		structure.getPrimaryKey().setValue(primarykey);
		structure.setEntityClass(entryCls);
	}

	@SuppressWarnings("unchecked")
	@Override
	public T find() {
		return (T) Assembler.create(QueryType.select, ResultType.Bean, structure, new PipelineFactory() {
			@Override
			public Pipeline getPipeline() {
				Pipeline pipeline = new PipelineDivice();
				pipeline.addLast(HandelFactory.commonFieldHandel());
				pipeline.addLast(HandelFactory.sqlHandel());
				pipeline.addLast(HandelFactory.primaryKeyHandel());
				pipeline.addLast(HandelFactory.conditionHandel());
				pipeline.addLast(HandelFactory.resultHandel());
				pipeline.addLast(HandelFactory.debugHandel());
				return pipeline;
			}
		});
	}

	@Override
	public int delete() {

		return (int) Assembler.create(QueryType.delete, ResultType.Int, structure, new PipelineFactory() {
			@Override
			public Pipeline getPipeline() {
				Pipeline pipeline = new PipelineDivice();
				pipeline.addLast(HandelFactory.sqlHandel());
				pipeline.addLast(HandelFactory.primaryKeyHandel());
				pipeline.addLast(HandelFactory.conditionHandel());
				pipeline.addLast(HandelFactory.resultHandel());
				pipeline.addLast(HandelFactory.debugHandel());
				return pipeline;
			}
		});

	}

}

==> cdm-core-2.0.7-sources.jar: online/sanen/cdm/QueryPKDevice.java <==
package online.sanen.cdm;

import online.sanen.cdm.api.QueryPK;
import online.sanen.cdm.api.basic.QueryType;
import online.sanen.cdm.api.basic.ResultType;
import online.sanen.cdm.api.basic.ChannelContext;
import online.sanen.cdm.api.component.Manager;
import online.sanen.cdm.api.component.Pipeline;
import online.sanen.cdm.api.component.PipelineDivice;
import online.sanen.cdm.api.factory.PipelineFactory;
import online.sanen.cdm.factory.HandelFactory;

/**
 * @author online.sanen Date: 2017/11/23 Time： 9:39
 */
public class QueryPKDevice<T> implements QueryPK<T> {
	ChannelContext context;

	public QueryPKDevice(Manager manager, Class<T> entryCls, Object primarykey) {
		context = new ChannelContext(manager);
		context.setEntityClass(entryCls);
		context.getPrimaryKey().setValue(primarykey);
	}

	@SuppressWarnings("unchecked")
	@Override
	public T find() {

		return (T) Assembler.create(QueryType.select, ResultType.Bean, context, new PipelineFactory() {
			@Override
			public Pipeline getPipeline() {
				Pipeline pipeline = new PipelineDivice();
				pipeline.addLast(HandelFactory.commonFieldHandel());
				pipeline.addLast(HandelFactory.sqlHandel());
				pipeline.addLast(HandelFactory.primaryKeyHandel());
				pipeline.addLast(HandelFactory.conditionHandel());
				pipeline.addLast(HandelFactory.resultHandel());
				pipeline.addLast(HandelFactory.debugHandel());
				return pipeline;
			}
		});
	}

	@Override
	public int delete() {

		return (int) Assembler.create(QueryType.delete, ResultType.Int, context, new PipelineFactory() {
			@Override
			public Pipeline getPipeline() {
				Pipeline pipeline = new PipelineDivice();
				pipeline.addLast(HandelFactory.sqlHandel());
				pipeline.addLast(HandelFactory.primaryKeyHandel());
				pipeline.addLast(HandelFactory.conditionHandel());
				pipeline.addLast(HandelFactory.resultHandel());
				pipeline.addLast(HandelFactory.debugHandel());
				return pipeline;
			}
		});

	}

}
